import tkinter as tk
import tkinter.filedialog as fd


class SimpleForm(tk.Tk):
    def __init__(self):
        super().__init__()

        # Config file content
        self.config_file = []
        self.target_file = ""

        # Menu
        menu = tk.Menu(self)

        # File Menu
        file_menu = tk.Menu(menu, tearoff=0)
        file_menu.add_command(label="New Search Profile", command=self.new_search)
        file_menu.add_command(label="Open Search Profile")
        file_menu.add_separator()
        file_menu.add_command(label="Save Searches")
        file_menu.add_command(label="Save as...")
        file_menu.add_separator()
        file_menu.add_command(label="Quit", command=self.destroy)

        # Run Menu
        run_menu = tk.Menu(menu, tearoff=0)
        run_menu.add_command(label="Run and Confirm - F8", command=self.run_search)
        run_menu.add_command(label="Run Without Confirmation - Ctrl+F8")

        # About Menu
        about_menu = tk.Menu(menu, tearoff=0)
        about_menu.add_command(label="About File Renamer")
        about_menu.add_command(label="Logs")

        # Menu Bar
        menu.add_cascade(label="File", menu=file_menu)
        menu.add_cascade(label="Run", menu=run_menu)
        menu.add_cascade(label="About", menu=about_menu)
        self.config(menu=menu)

        # First RegEx
        self.expressionOne_label = tk.Label(self, width=15, text="Expression 1", anchor="w")
        self.expressionOne_input = tk.Entry(self, width=25)

        # Folder Select
        self.folderSelector_btn = tk.Button(self, width=10, text="Select Folder", command=self.folder_selector)

        # 2nd RegEx
        self.expressionTwo_label = tk.Label(self, width=15, text="Expression 2", anchor="w")
        self.expressionTwo_input = tk.Entry(self, width=25)

        # Functions
        self.clearSearch_btn = tk.Button(self, width=25, text="Clear Expressions", command=self.clear_form)

        # Formatting in grid
        self.expressionOne_label.grid(padx=5, pady=5, row=0, column=0)
        self.expressionOne_input.grid(padx=5, pady=5, row=0, column=1)
        self.folderSelector_btn.grid(padx=5, pady=5, row=0, column=2)
        self.expressionTwo_label.grid(padx=5, pady=5, row=1, column=0)
        self.expressionTwo_input.grid(padx=5, pady=5, row=1, column=1)
        self.clearSearch_btn.grid(padx=5, pady=5, row=2, column=0)

    # Main page commands
    def clear_form(self):
        self.expressionOne_input.delete(0, tk.END)
        self.expressionTwo_input.delete(0, tk.END)
        self.expressionOne_input.focus_set()

    def folder_selector(self):
        directory = fd.askdirectory(title="Open	directory", initialdir="/")
        if directory:
            print(directory)
        else:
            print("No folder selected")

    # Menu commands
    def new_search(self):

        string_of_configList = ""

        for line in self.config_file:
            string_of_configList += str(line) + "\n"

        new_file = fd.asksaveasfile(title="Create new search",
                                    defaultextension=".config",
                                    filetypes=(("Text files", "*.json"),))
        if new_file:
            new_file.write(string_of_configList)
            new_file.close()
            self.target_file = new_file

    # Menu commands
    def save_search(self):

        string_of_configList = ""

        for line in self.config_file:
            string_of_configList += str(line) + "\n"

        self.target_filetarget_file.write(string_of_configList)
        self.target_file.close()


    def run_search(self):

        expression1 = self.expressionOne_input.get()
        expression2 = self.expressionTwo_input.get()
        self.config_file.append(expression1)
        self.config_file.append(expression2)




if __name__ == "__main__":
    app = SimpleForm()
    app.title("Simple Form")
    app.mainloop()